==> ejc-credentials-impl-3.0.0-20220511.085154-8-sources.jar: com/ejianc/certify/bean/SocialInsuranceEntity.java <==
package com.ejianc.certify.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 社保档案
 *
 * @author generator
 *
 */
 @TableName("bd_social_insurance")
public class SocialInsuranceEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="pk_psnid")
    private String pkPsnid; // 人员主键
    @TableField(value="pk_sbzt")
    private String pkSbzt; // 社保主体
    @TableField(value="psn_name")
    private String psnName; // 姓名
    @TableField(value="card_id")
    private String cardId; // 身份证号码
    @TableField(value="sb_month")
    private String sbMonth; // 社保月份
    @TableField(value="ts")
    private Date ts; // 时间戳
    @TableField(value="pk_org")
    private String pkOrg; // 创建人组织




    public String getPkPsnid() {
        return pkPsnid;
    }

    public void setPkPsnid(String pkPsnid) {
        this.pkPsnid = pkPsnid;
    }
    public String getPkSbzt() {
        return pkSbzt;
    }

    public void setPkSbzt(String pkSbzt) {
        this.pkSbzt = pkSbzt;
    }
    public String getPsnName() {
        return psnName;
    }

    public void setPsnName(String psnName) {
        this.psnName = psnName;
    }
    public String getCardId() {
        return cardId;
    }

    public void setCardId(String cardId) {
        this.cardId = cardId;
    }
    public String getSbMonth() {
        return sbMonth;
    }

    public void setSbMonth(String sbMonth) {
        this.sbMonth = sbMonth;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public String getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(String pkOrg) {
        this.pkOrg = pkOrg;
    }

}

==> ejc-credentials-impl-3.0.0-20220518.110548-20-sources.jar: com/ejianc/certify/bean/SocialInsuranceEntity.java <==
package com.ejianc.certify.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 社保档案
 *
 * @author generator
 *
 */
 @TableName("bd_social_insurance")
public class SocialInsuranceEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="pk_psnid")
    private String pkPsnid; // 人员主键
    @TableField(value="pk_sbzt")
    private String pkSbzt; // 社保主体
    @TableField(value="psn_name")
    private String psnName; // 姓名
    @TableField(value="card_id")
    private String cardId; // 身份证号码
    @TableField(value="sb_month")
    private String sbMonth; // 社保月份
    @TableField(value="ts")
    private Date ts; // 时间戳
    @TableField(value="pk_org")
    private Long pkOrg; // 创建人组织

    public String getPkPsnid() {
        return pkPsnid;
    }

    public void setPkPsnid(String pkPsnid) {
        this.pkPsnid = pkPsnid;
    }
    public String getPkSbzt() {
        return pkSbzt;
    }

    public void setPkSbzt(String pkSbzt) {
        this.pkSbzt = pkSbzt;
    }
    public String getPsnName() {
        return psnName;
    }

    public void setPsnName(String psnName) {
        this.psnName = psnName;
    }
    public String getCardId() {
        return cardId;
    }

    public void setCardId(String cardId) {
        this.cardId = cardId;
    }
    public String getSbMonth() {
        return sbMonth;
    }

    public void setSbMonth(String sbMonth) {
        this.sbMonth = sbMonth;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public Long getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }

}
